==> haskell-hls-splice-plugin-2.1.0.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-splice-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-splice-plugin-2.1.0.0-5K3dsoGup8M5MGpSB5YwcS
key:                  hls-splice-plugin-2.1.0.0-5K3dsoGup8M5MGpSB5YwcS
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  548dd921580d09070c7568d8543dd28e
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.1.0.0-5K3dsoGup8M5MGpSB5YwcS
depends:
    aeson-2.1.2.1-LDc25PpdH5WHlLB8Mcp2Rh base-4.17.2.1 containers-0.6.7
    dlist-1.0-BKgPi70fx5AJreCYiKxIIN
    extra-1.7.16-EVqIvjfjup2KjWh1SyzBng
    foldl-1.4.18-89NBv65cq5Y6fn0zbXjw0q ghc-9.4.8
    ghc-exactprint-1.6.1-B5i7prcXWgZ8MDaBFsAria
    ghcide-2.1.0.0-JBq8BlG0DEi1qEeHQWL9pq
    hls-plugin-api-2.1.0.0-8OzZBCSKxFIKibsC3x3Rbf
    hls-refactor-plugin-2.1.0.0-KZv8gopQQ38LKxl8QnDfpz
    lens-5.3-FNJYFG5nVy3K1UtPWTWg2x lsp-2.1.0.0-5voKI1DXTs5JAKa5U64Eo4
    mtl-2.2.2 retrie-1.2.3-Cs9ZPcmCGd9CIGqJ8B98tW
    syb-0.7.2.4-LBhYOmNvCTD9nmTNYbjxYb text-2.0.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-splice-plugin-2.1.0.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-splice-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-splice-plugin-2.1.0.0-IgKkf216nY2FRyScWapPLC
key:                  hls-splice-plugin-2.1.0.0-IgKkf216nY2FRyScWapPLC
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  a00735fbbb12b306c3298dfc812972e1
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-splice-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.1.0.0-IgKkf216nY2FRyScWapPLC
depends:
    aeson-2.1.2.1-LDc25PpdH5WHlLB8Mcp2Rh base-4.17.2.1 containers-0.6.7
    dlist-1.0-BKgPi70fx5AJreCYiKxIIN
    extra-1.7.16-EVqIvjfjup2KjWh1SyzBng
    foldl-1.4.18-89NBv65cq5Y6fn0zbXjw0q ghc-9.4.8
    ghc-exactprint-1.6.1-B5i7prcXWgZ8MDaBFsAria
    ghcide-2.1.0.0-Eba7IKOMlUg1JSq9BskH28
    hls-plugin-api-2.1.0.0-AS7TpGIV2D21ChjWdaeqTl
    hls-refactor-plugin-2.1.0.0-AasUOxuAq9J5pcxJZY82L0
    lens-5.3.1-3FYsDpCHEKEBLMSbQ9nAqF
    lsp-2.1.0.0-DyFP5ixOoJMD0lbV6POXwv mtl-2.2.2
    retrie-1.2.3-Cs9ZPcmCGd9CIGqJ8B98tW
    syb-0.7.2.4-LBhYOmNvCTD9nmTNYbjxYb text-2.0.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
